package com.ruoyi.abuwx.mapper;

import com.ruoyi.abuwx.domain.QuestionSpecial;

import java.util.List;

/**
 * 专项管理Mapper接口
 *
 * @author lujie
 * @date 2025-01-07
 */
public interface QuestionSpecialMapper {
    /**
     * 查询专项管理
     *
     * @param id 专项管理主键
     * @return 专项管理
     */
    public QuestionSpecial selectQuestionSpecialById(Long id);

    /**
     * 查询专项管理列表
     *
     * @param questionSpecial 专项管理
     * @return 专项管理集合
     */
    public List<QuestionSpecial> selectQuestionSpecialList(QuestionSpecial questionSpecial);

    /**
     * 新增专项管理
     *
     * @param questionSpecial 专项管理
     * @return 结果
     */
    public int insertQuestionSpecial(QuestionSpecial questionSpecial);

    /**
     * 修改专项管理
     *
     * @param questionSpecial 专项管理
     * @return 结果
     */
    public int updateQuestionSpecial(QuestionSpecial questionSpecial);

    /**
     * 删除专项管理
     *
     * @param id 专项管理主键
     * @return 结果
     */
    public int deleteQuestionSpecialById(Long id);

    /**
     * 批量删除专项管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteQuestionSpecialByIds(Long[] ids);
}
